%% MIMO System under saturations with anti-wind up controller
% taken from "New results for analysis of systems with repeated
% nonlinearities"
% F.J. D'Amato, M.A. Rotea, A.V. Megretski, U.T. Joensson
% Automatica 2000
clear all

SatDim =2;

Plant(:,:,1) = ss(tf([10],[100 1])*[4 -5;-3 4]);
Plant(:,:,2) = ss(tf([10],[90 1])*[4 -5;-3 4]);

% controller with anti wind up from thesis of Kothare
Ptilde = tf([10],[100 1])*[4 tf(-5,[0.1 1]);tf(-3,[0.1 1]) 4];
Q1 = 2.5*tf([1 1],[20 1])*tf(1,[0.1 1])*[tf([1.6 1],1), tf(2,1); tf(1.2,1),...
    tf([1.6 1],1)];
Q2 = tf(1,[100,1])*[99, -125*tf([1 1],[0.1 1]); -75*tf([1 1],[0.1 1]), 99];

%build closed loop interconnection
systemnames = 'Plant Ptilde Q1 Q2';
inputvar = '[w{2}; d{2}]';
outputvar = '[Q1-Q2; w]';
input_to_Plant = '[d+w]';
input_to_Ptilde = '[w]';
input_to_Q1 = '[-Plant+Ptilde]';
input_to_Q2 = '[w]';
cleanupsysic = 'yes';
Pic = sysic;

%% IQC analysis for LTI Points

% constant IQC point 1
[giqclmi1,info1] = simplesaturationgain(Pic(:,:,1),SatDim);

% note that the stability margins (1/gamma) in the D'Amato paper are
% 0.128 for what they call quadratic Lyapunov function, 0.242 for Zames-Falb
% and 0.309 for their new IQC.

% constant IQC point 2
[giqclmi2,info2] = simplesaturationgain(Pic(:,:,2),SatDim);

%% IQC analysis for LPV system

% constant IQC
[giqclmi3,info3] = simplesaturationgain(Pic,SatDim);

% parameter varying IQC
[giqclmi4,info4] = simplesaturationgain(Pic,SatDim,0);


